@@ -1,9 +1,12 @@
 import os
+import sys
 import json
 import tqdm
 import logging
 import requests
 from transformers import set_seed
+from transformers import HfArgumentParser
+from pytorch_lightning import _logger as lightning_logger
 
 
 REMOTE_DATA_MAP = {
@@ -31,6 +34,16 @@ REMOTE_DATA_MAP = {
             "fname": "test.txt",
         },
     },
+    "korquad-v1": {
+        "train": {
+            "web_url": "https://korquad.github.io/dataset/KorQuAD_v1.0_train.json",
+            "fname": "KorQuAD_v1.0_train.json",
+        },
+        "val": {
+            "web_url": "https://korquad.github.io/dataset/KorQuAD_v1.0_dev.json",
+            "fname": "KorQuAD_v1.0_dev.json",
+        }
+    }
 }
 
 REMOTE_MODEL_MAP = {
@@ -225,19 +238,20 @@ def web_download(url,
 def download_downstream_dataset(args):
     data_name = args.downstream_corpus_name.lower()
     if data_name in REMOTE_DATA_MAP.keys():
+        cache_dir = os.path.join(args.downstream_corpus_root_dir, data_name)
         for value in REMOTE_DATA_MAP[data_name].values():
             if "web_url" in value.keys():
                 web_download(
                     url=value["web_url"],
                     save_fname=value["fname"],
-                    cache_dir=args.downstream_corpus_dir,
+                    cache_dir=cache_dir,
                     force_download=args.force_download,
                 )
             else:
                 google_download(
                     file_id=value["googledrive_file_id"],
                     save_fname=value["fname"],
-                    cache_dir=args.downstream_corpus_dir,
+                    cache_dir=cache_dir,
                     force_download=args.force_download
                 )
     else:
@@ -275,6 +289,9 @@ def download_pretrained_model(args):
 
 
 def set_logger(args):
+    # 파이토치 라이트닝이 학습 초반부에 로그를 두 번씩 찍는 버그가 있어
+    # 이를 해결하기 위해 handler를 빈 리스트로 초기화한다
+    lightning_logger.handlers = []
     logging.basicConfig(
         format="%(asctime)s - %(levelname)s - %(name)s -   %(message)s",
         datefmt="%m/%d/%Y %H:%M:%S",
@@ -300,3 +317,14 @@ def check_exist_checkpoints(args):
 def seed_setting(args):
     set_seed(args.seed)
     logger.info(f"complete setting seed({args.seed})")
+
+
+def load_arguments(argument_class, json_file_path=None):
+    parser = HfArgumentParser(argument_class)
+    if json_file_path is not None:
+        args, = parser.parse_json_file(json_file=json_file_path)
+    elif len(sys.argv) == 2 and sys.argv[1].endswith(".json"):
+        args, = parser.parse_json_file(json_file=os.path.abspath(sys.argv[1]))
+    else:
+        args, = parser.parse_args_into_dataclasses()
+    return args
\ No newline at end of file
